@@ -62,11 +62,6 @@ class Client:
 
         self.base_url, self.base_url_glz, self.base_url_shared = self.__build_urls()
 
-    def activate_from_headers(self,headers,puuid) -> None:
-        '''Activate the client if you already have headers''' 
-        self.headers = headers
-        self.puuid = puuid
-
     def activate(self) -> None:
         '''Activate the client and get authorization'''
         try:
